summaryrefslogtreecommitdiffstatshomepage
path: root/src
diff options
context:
space:
mode:
author hap <happppp@users.noreply.github.com>2015-07-28 23:18:51 +0200
committer hap <happppp@users.noreply.github.com>2015-07-28 23:18:51 +0200
commit4ff4652fa54ee2b5e99dee9004e83819b621ac73 (patch)
tree7ef61cf188dc323d6ddd2d63a71e55d313d5b809 /src
parent971b102f5368f84efac3b6f65233927391866a8d (diff)
note
Diffstat (limited to 'src')
-rw-r--r--src/mess/drivers/elecbowl.c4
-rw-r--r--src/mess/drivers/hh_cop400.c2
-rw-r--r--src/mess/drivers/hh_melps4.c4
-rw-r--r--src/mess/drivers/hh_pic16.c2
-rw-r--r--src/mess/drivers/hh_tms1k.c24
-rw-r--r--src/mess/drivers/hh_ucom4.c34
-rw-r--r--src/mess/drivers/mbdtower.c2
-rw-r--r--src/mess/drivers/wildfire.c4
8 files changed, 38 insertions, 38 deletions
diff --git a/src/mess/drivers/elecbowl.c b/src/mess/drivers/elecbowl.c
index 3d65d7b3d74..8c56c5f3587 100644
--- a/src/mess/drivers/elecbowl.c
+++ b/src/mess/drivers/elecbowl.c
@@ -14,8 +14,8 @@
* edge connector to sensors(switches trigger when ball rolls over)
and other inputs
- lamp translation table: SN74259.u5(mux 1) goes to MESS output lamp5x,
- SN74259.u6(mux 2) goes to MESS output lamp6x. u1-u3 are SN75492 ICs,
+ lamp translation table: SN74259.u5(mux 1) goes to MAME output lamp5x,
+ SN74259.u6(mux 2) goes to MAME output lamp6x. u1-u3 are SN75492 ICs,
where other: u1 A2 is N/C, u3 A1 is from O2 and goes to digits seg C.
u5 Q0 -> u1 A4 -> L2 (pin #2) u6 Q0 -> u3 A4 -> L1 (pin #1)
diff --git a/src/mess/drivers/hh_cop400.c b/src/mess/drivers/hh_cop400.c
index 568ccd6644e..3fe4e2da2ff 100644
--- a/src/mess/drivers/hh_cop400.c
+++ b/src/mess/drivers/hh_cop400.c
@@ -284,7 +284,7 @@ MACHINE_CONFIG_END
The first version was on TMS1100 (see hh_tms1k.c), this is the reprogrammed
second release with a gray case instead of black.
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
diff --git a/src/mess/drivers/hh_melps4.c b/src/mess/drivers/hh_melps4.c
index b9db9475c2f..dcc1322b134 100644
--- a/src/mess/drivers/hh_melps4.c
+++ b/src/mess/drivers/hh_melps4.c
@@ -224,7 +224,7 @@ INPUT_CHANGED_MEMBER(hh_melps4_state::reset_button)
* Mitsubishi M58846-701P MCU
* cyan/red/green VFD display Itron CP5090GLR R1B, with partial color overlay
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -339,7 +339,7 @@ MACHINE_CONFIG_END
* Mitsubishi M58846-702P MCU
* cyan/red/green VFD display Itron CP5143GLR SGA, with light-yellow color overlay
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
diff --git a/src/mess/drivers/hh_pic16.c b/src/mess/drivers/hh_pic16.c
index a7542e6d31d..7b9e8335e58 100644
--- a/src/mess/drivers/hh_pic16.c
+++ b/src/mess/drivers/hh_pic16.c
@@ -15,7 +15,7 @@
*192 1650 19??, (a phone dialer, have dump)
*255 1655 19??, (a talking clock, have dump)
- (* denotes not yet emulated by MESS, @ denotes it's in this driver)
+ (* denotes not yet emulated by MAME, @ denotes it's in this driver)
TODO:
diff --git a/src/mess/drivers/hh_ucom4.c b/src/mess/drivers/hh_ucom4.c
index a6c9301e988..d40a36cd4a1 100644
--- a/src/mess/drivers/hh_ucom4.c
+++ b/src/mess/drivers/hh_ucom4.c
@@ -50,7 +50,7 @@
*128 uPD650C 1981, Roland TR-606
133 uPD650C 1982, Roland TB-303 -> tb303.c
- (* denotes not yet emulated by MESS, @ denotes it's in this driver)
+ (* denotes not yet emulated by MAME, @ denotes it's in this driver)
***************************************************************************/
@@ -229,7 +229,7 @@ UINT8 hh_ucom4_state::read_inputs(int columns)
- Japan: "Missile Guerilla Warfare Maneuvers", published by Tomy
- World: UFO Master-Blaster Station
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -341,7 +341,7 @@ MACHINE_CONFIG_END
Then choose a formation(A,B,C) and either pass the ball, and/or start
running. For more information, refer to the official manual.
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -481,7 +481,7 @@ MACHINE_CONFIG_END
player 1 presses one of the directional keys. In 2-player mode, player 2
controls the goalkeeper, defensive players are still controlled by the CPU.
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -603,7 +603,7 @@ MACHINE_CONFIG_END
* NEC uCOM-44 MCU, labeled EMIX D552C 049
* cyan VFD display Emix-108
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -712,7 +712,7 @@ MACHINE_CONFIG_END
This is basically a revamp of their earlier Boxing game (ET-06), case and
buttons are exactly the same.
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -865,7 +865,7 @@ MACHINE_CONFIG_END
- Japan: FL Crazy Climbing
- USA: Crazy Climber
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -967,7 +967,7 @@ MACHINE_CONFIG_END
- USA: Invader From Space
- UK: Invader From Space, published by Grandstand
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -1179,7 +1179,7 @@ MACHINE_CONFIG_END
- Japan: Astro Wars
- UK: Astro Wars, published by Grandstand
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -1281,7 +1281,7 @@ MACHINE_CONFIG_END
- USA: Astro Command, published by Tandy
- UK: Scramble, published by Grandstand
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -1390,7 +1390,7 @@ MACHINE_CONFIG_END
- USA: Dracula, red case
- Other: Dracula, yellow case, published by Hales
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -1589,7 +1589,7 @@ MACHINE_CONFIG_END
- USA: Cosmic Combat
- Japan: Space Attack
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -1688,7 +1688,7 @@ MACHINE_CONFIG_END
Press the Serve button to start, then hit the ball by pressing one of the
positional buttons when the ball flies over it.
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -1850,7 +1850,7 @@ MACHINE_CONFIG_END
The game will start automatically after turning it on. This Pac Man refuses
to eat dots with his butt, you can only eat them going right-to-left.
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -1954,7 +1954,7 @@ MACHINE_CONFIG_END
- UK: Astro Blaster, published by Hales (Epoch Astro Command was named Scramble)
- Germany: Rambler
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -2055,7 +2055,7 @@ MACHINE_CONFIG_END
- USA: Caveman, published by Tandy
- UK: Cave Man - Jr. Caveman vs Dinosaur, published by Grandstand
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -2154,7 +2154,7 @@ MACHINE_CONFIG_END
To start the game, simply press [UP]. Hold a joystick direction to move around.
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
diff --git a/src/mess/drivers/mbdtower.c b/src/mess/drivers/mbdtower.c
index 2502c38c2a6..6d122b960e4 100644
--- a/src/mess/drivers/mbdtower.c
+++ b/src/mess/drivers/mbdtower.c
@@ -13,7 +13,7 @@
This is a board game, it obviously requires game pieces and the board.
The emulated part is the centerpiece, a black tower with a rotating card
panel and LED digits for displaying health, amount of gold, etc. As far
- as MESS is concerned, the game works fine.
+ as MAME is concerned, the game works fine.
To start up the game, first press [MOVE], the machine now does a self-test.
Then select level and number of players and the game will start. Read the
diff --git a/src/mess/drivers/hh_tms1k.c b/src/mess/drivers/hh_tms1k.c
index a6bcf406bb0..8829fa38ed8 100644
--- a/src/mess/drivers/hh_tms1k.c
+++ b/src/mess/drivers/hh_tms1k.c
@@ -78,7 +78,7 @@
*M95041 ? 1983, Tsukuda Game Pachinko (? note: 40-pin, VFD-capable)
@CD7282SL TMS1100 1981, Tandy/RadioShack Tandy-12 (serial is similar to TI Speak & Spell series?)
- (* denotes not yet emulated by MESS, @ denotes it's in this driver)
+ (* denotes not yet emulated by MAME, @ denotes it's in this driver)
TODO:
@@ -911,7 +911,7 @@ MACHINE_CONFIG_END
This is a head to head electronic tabletop LED-display sports console.
One cartridge(Football) was included with the console, the other three were
sold in a pack. Gameplay has emphasis on strategy, read the official manual
- on how to play. Remember that you can rotate the view in MESS: rotate left
+ on how to play. Remember that you can rotate the view in MAME: rotate left
for Home(P1) orientation, rotate right for Visitor(P2) orientation.
Cartridge socket:
@@ -1076,7 +1076,7 @@ MACHINE_CONFIG_END
are denoted by words ("left", "center", "short", etc), and an alternate one
with little guys drawn next to the LEDs.
- lamp translation table: led LDzz from game PCB = MESS lampyx:
+ lamp translation table: led LDzz from game PCB = MAME lampyx:
LD0 = - LD10 = lamp12 LD20 = lamp42 LD30 = lamp60
LD1 = lamp23 LD11 = lamp4 LD21 = lamp41 LD31 = lamp61
@@ -1209,7 +1209,7 @@ MACHINE_CONFIG_END
The sequel to Entex Baseball, this version keeps up with score and innings.
As its predecessor, the pitcher controls are on a separate joypad.
- lamp translation table: led zz from game PCB = MESS lampyx:
+ lamp translation table: led zz from game PCB = MAME lampyx:
00 = - 10 = lamp94 20 = lamp74 30 = lamp50
01 = lamp53 11 = lamp93 21 = lamp75 31 = lamp51
@@ -1335,7 +1335,7 @@ MACHINE_CONFIG_END
This is another improvement over Entex Baseball, where gameplay is a bit more
varied. Like the others, the pitcher controls are on a separate joypad.
- lamp translation table: led zz from game PCB = MESS lampyx:
+ lamp translation table: led zz from game PCB = MAME lampyx:
note: unlabeled panel leds are listed here as Sz, Bz, Oz, Iz, z left-to-right
00 = - 10 = lamp75 20 = lamp72
@@ -1517,7 +1517,7 @@ MACHINE_CONFIG_END
TMS1100, the second more widespread release runs on a COP400. There are
also differences with the overlay mask.
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -1748,7 +1748,7 @@ MACHINE_CONFIG_END
* TMS1100 6010 MP1218 (die also labeled MP1218)
* 4 7seg LEDs, and other LEDs behind bezel, 1bit sound
- lamp translation table: led zz from game PCB = MESS lampyx:
+ lamp translation table: led zz from game PCB = MAME lampyx:
11 = lamp90 21 = lamp91 31 = lamp92 41 = lamp93 51 = lamp95
12 = lamp80 22 = lamp81 32 = lamp82 42 = lamp83 52 = lamp85
@@ -1873,7 +1873,7 @@ MACHINE_CONFIG_END
* TMS1100 MP1221 (die labeled MP1221)
* 4 7seg LEDs(rightmost one unused), and other LEDs behind bezel, 1bit sound
- lamp translation table: led zz from game PCB = MESS lampyx:
+ lamp translation table: led zz from game PCB = MAME lampyx:
0 = - 10 = lamp44 20 = lamp53 30 = lamp95 40 = lamp92
1 = lamp30 11 = lamp45 21 = lamp54 31 = lamp85 41 = lamp93
@@ -1886,7 +1886,7 @@ MACHINE_CONFIG_END
8 = lamp42 18 = lamp73 28 = lamp84 38 = lamp82
9 = lamp43 19 = - 29 = lamp94 39 = lamp83
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
***************************************************************************/
@@ -3684,7 +3684,7 @@ READ8_MEMBER(bankshot_state::read_k)
// config
/* physical button layout and labels is like this:
- (note: remember that you can rotate the display in MESS)
+ (note: remember that you can rotate the display in MAME)
[SELECT [BALL UP] [BALL OVER]
SCORE]
@@ -4019,7 +4019,7 @@ MACHINE_CONFIG_END
- Japan: Block Attack
- UK: Break-In
- lamp translation table: led zz from game PCB = MESS lampyx:
+ lamp translation table: led zz from game PCB = MAME lampyx:
00 = - 10 = lamp50 20 = lamp42
01 = lamp70 11 = lamp51 21 = lamp33
@@ -4619,5 +4619,5 @@ CONS( 1981, tandy12, 0, 0, tandy12, tandy12, driver_device, 0, "Tan
CONS( 1979, tbreakup, 0, 0, tbreakup, tbreakup, driver_device, 0, "Tomy", "Break Up (Tomy)", GAME_SUPPORTS_SAVE )
// ***: As far as MESS is concerned, the game is emulated fine. But for it to be playable, it requires interaction
// with other, unemulatable, things eg. game board/pieces, playing cards, pen & paper, etc.
@@ -4619,5 +4619,5 @@ CONS( 1981, tandy12, 0, 0, tandy12, tandy12, driver_device, 0, "Tan
CONS( 1979, tbreakup, 0, 0, tbreakup, tbreakup, driver_device, 0, "Tomy", "Break Up (Tomy)", GAME_SUPPORTS_SAVE )
-// ***: As far as MESS is concerned, the game is emulated fine. But for it to be playable, it requires interaction
+// ***: As far as MAME is concerned, the game is emulated fine. But for it to be playable, it requires interaction
// with other, unemulatable, things eg. game board/pieces, playing cards, pen & paper, etc.
diff --git a/src/mess/drivers/wildfire.c b/src/mess/drivers/wildfire.c
index 03dc325fd18..b903f86dfa4 100644
--- a/src/mess/drivers/wildfire.c
+++ b/src/mess/drivers/wildfire.c
@@ -9,7 +9,7 @@
to create the illusion of a moving ball, and even the flippers are leds.
A drawing of a pinball table is added as overlay.
- NOTE!: MESS external artwork is recommended
+ NOTE!: MAME external artwork is recommended
TODO:
@@ -90,7 +90,7 @@ inline bool wildfire_state::index_is_7segled(int index)
return (index < 3);
}
// lamp translation table: Lzz from patent US4334679 FIG.4 = MESS lampxxy,
// where xx is led column and y is led row, eg. lamp103 is output A10 D3
// (note: 2 mistakes in the patent: the L19 between L12 and L14 should be L13, and L84 should of course be L48)
/*
@@ -90,7 +90,7 @@ inline bool wildfire_state::index_is_7segled(int index)
return (index < 3);
}
-// lamp translation table: Lzz from patent US4334679 FIG.4 = MESS lampxxy,
+// lamp translation table: Lzz from patent US4334679 FIG.4 = MAME lampxxy,
// where xx is led column and y is led row, eg. lamp103 is output A10 D3
// (note: 2 mistakes in the patent: the L19 between L12 and L14 should be L13, and L84 should of course be L48)